package gov.va.nvap.server.endpoint.adapter.announce.transformer;

import gov.va.nvap.common.transformer.Transformer;
import gov.va.nvap.common.transformer.TransformerException;
import gov.va.nvap.common.validation.Assert;
import gov.va.nvap.common.validation.NullChecker;
import gov.va.nvap.svc.consentmgmt.stub.adapter.announce.data.Announcement;
import gov.va.nvap.svc.consentmgmt.stub.adapter.announce.jaxb.AnnouncePatientRequest;
import gov.va.nvap.svc.consentmgmt.stub.adapter.announce.jaxb.AuthorizedOrganizationType;
import gov.va.nvap.svc.consentmgmt.stub.adapter.announce.jaxb.PatientType;

/**
 * Transformer for transforming the PIP Announcement object to
 * AnnouncePatientRequest. NOTE: This transformer does not set the UserType that
 * is required in the AnnouncePatientRequest.
 * 
 * @author Asha Amritraj
 */
public class AnnouncementToAnnouncePatientRequest implements
		Transformer<Announcement, AnnouncePatientRequest> {

	@Override
	public AnnouncePatientRequest transform(final Announcement announcement)
			throws TransformerException {
		Assert.assertNotEmpty(announcement, "Announcement cannot be null!");
//		Assert.assertNotEmpty(announcement.getTargetOrganization(),
//				"Atleast one targeted organization is required with announcement!");

		// Populate the AnnouncePatientRequest object
		final AnnouncePatientRequest announcePatientRequest = new AnnouncePatientRequest();
		announcePatientRequest.setAnnouncementId(announcement
				.getAnnouncementId());
		// Cannot set the batch id because its a sequence
		// announcePatientRequest.setBatchId(announcement.getBatchId());
		announcePatientRequest.setCreatedDate(announcement.getCreatedTs());
		announcePatientRequest.setCompletedDate(announcement.getCompletedTs());
		announcePatientRequest.setScheduledDate(announcement.getScheduledTs());
		// Set patient
		final PatientType patientType = new PatientType();
        if (NullChecker.isNotEmpty(announcement.getPatientIen())) {
            patientType.setPatientId(announcement.getPatientIen());
        } else {
            patientType.setPatientId(announcement.getPatientConsentDir().getPatientIen());
        }
		announcePatientRequest.setPatient(patientType);
		announcePatientRequest.setScheduledDate(announcement.getScheduledTs());
		// Set authorized organization
		AuthorizedOrganizationType organization = null;
        if (announcement.getTargetOrganization() != null) {
            organization = new AuthorizedOrganizationType();
            organization.setOrgName(announcement.getTargetOrganization()
                    .getOrgName());
            organization.setOrgNumber(announcement.getTargetOrganization()
                    .getOrgNumber());
            organization
                    .setOrgOid(announcement.getTargetOrganization().getOrgOid());
        }
		announcePatientRequest.getAuthorizedOrganizations().add(organization);
		return announcePatientRequest;
	}
}
