/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package gov.va.nvap.svc.facility.jpa.impl;

import gov.va.nvap.svc.facility.data.Facility;
import gov.va.nvap.svc.facility.intf.EntityDoesNotExistException;
import gov.va.nvap.svc.facility.intf.PreexistingEntityException;
import gov.va.nvap.svc.facility.jpa.intf.FacilityControllerInterface;

import java.util.Collection;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityNotFoundException;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

/**
 * 
 * @author DNS   egberb
 */
public class FacilityJpaController implements FacilityControllerInterface {

	@PersistenceContext(name = "VapEntityManager")
	private EntityManager em;

	@Override
	public void create(final Facility facility)
			throws PreexistingEntityException, Exception {
		try {
			this.em.persist(facility);
		} catch (final Exception ex) {
			if (this.findFacility(facility.getFacilityId()) != null) {
				throw new PreexistingEntityException("Facility " + facility
						+ " already exists.", ex);
			}
			throw ex;
		}
	}

	public void destroy(final Long id) throws EntityDoesNotExistException {
		this.em.getTransaction().begin();
		Facility facility;
		try {
			facility = this.em.getReference(Facility.class, id);
			facility.getFacilityId();
		} catch (final EntityNotFoundException enfe) {
			throw new EntityDoesNotExistException("The facility with id " + id
					+ " no longer exists.", enfe);
		}
		this.em.remove(facility);
		this.em.getTransaction().commit();
	}

	@Override
	public void edit(Facility facility) throws EntityDoesNotExistException,
			Exception {
		try {
			facility = this.em.merge(facility);
		} catch (final Exception ex) {
			final String msg = ex.getLocalizedMessage();
			if ((msg == null) || (msg.length() == 0)) {
				final Long id = facility.getFacilityId();
				if (this.findFacility(id) == null) {
					throw new EntityDoesNotExistException(
							"The facility with id " + id + " no longer exists.",
							ex);
				}
			}
			throw ex;
		}
	}

	@Override
	public Collection<Facility> findAllowedFacilities() {
		final Query q = this.em.createNamedQuery("Facility.findByAllowed");
		q.setParameter("allowed", true);
		return q.getResultList();
	}

	@Override
	public Facility findFacility(final Long id) {
		return this.em.find(Facility.class, id);
	}

	@Override
	public Facility findFacilityByStationNumber(final String stationId) throws EntityDoesNotExistException {
		try {
			final Query q = this.em
					.createNamedQuery("Facility.findByFacilityStation");
			q.setParameter("facilityStation", stationId);
			return ((Facility) q.getSingleResult());
		} catch (final Exception e) {
			throw new EntityDoesNotExistException(
					"Cannot find facility for Station Number [" + stationId + "]. ",
					e);
		}

	}

	@Override
	public List<Facility> findFacilityEntities() {
		return this.findFacilityEntities(true, -1, -1);
	}

	private List<Facility> findFacilityEntities(final boolean all,
			final int maxResults, final int firstResult) {
		final Query q = this.em
				.createQuery("select object(o) from Facility as o order by LOWER(facilityName)");
		if (!all) {
			q.setMaxResults(maxResults);
			q.setFirstResult(firstResult);
		}
		return q.getResultList();
	}

	@Override
	public List<Facility> findFacilityEntities(final int maxResults,
			final int firstResult) {
		return this.findFacilityEntities(false, maxResults, firstResult);
	}

	public int getFacilityCount() {
		final Query q = this.em
				.createQuery("select count(o) from Facility as o");
		return ((Long) q.getSingleResult()).intValue();
	}

	public void setEntityManager(final EntityManager em) {
		this.em = em;
	}
}
