<%-- 
    Document   : patientDiscoverySummaryReport
    Created on : Jun 5, 2015, 12:04:48 PM
    Author     : Irakli Kakushadze
--%>

<%@taglib uri="http://java.sun.com/jsp/jstl/core" prefix="c"%>
<%@taglib uri="http://java.sun.com/jsp/jstl/fmt" prefix="fmt"%>
<%@taglib uri="http://java.sun.com/jsp/jstl/functions" prefix="fn"%>
<%@taglib tagdir="/WEB-INF/tags/cpp" prefix="cpp"%>
<%@taglib tagdir="/WEB-INF/tags/date" prefix="date"%>
<%@taglib tagdir="/WEB-INF/tags/formatting" prefix="f" %>
<%@page import="java.util.*"%>

<%
    String userName = request.getRemoteUser();
%>

<f:mainTemplate headerText="Patient Discovery Audit Summary Report" userName="<%=userName%>">
    <script language="JavaScript">
        $(document).ready(function () {
            $("#startDate").datepicker({
                maxDate: 0,
                dateFormat: 'mm/dd/yy',
                onClose: function (selectedDate) {
                    $("#endDate").datepicker("option", "minDate", selectedDate);
                }
            });

            $("#endDate").datepicker({
                maxDate: 0,
                dateFormat: 'mm/dd/yy',
                onClose: function (selectedDate) {
                    $("#startDate").datepicker("option", "maxDate", selectedDate);
                }
            });
            
            var reportTable;

            //updates datatables with ajaxed data along with audit count
            reportTable = $('#reportTable').DataTable({
                destroy: true,
                ajax: { 
                    url: constructUrl("doSearch"),
                    dataSrc: function(json){
                        $('.dataTables_empty').remove();
                        return json.data;
                    },
                    error: function(o){
                        handleErrorsInDataTable('reportTable', o, 9);
                    }
                }, 
                info: false,
                language: {
                    emptyTable: "No records found"
                },
                ordering: true,
                paging: false,
                processing: true,
                searching: false,
                serverSide: true,
                columnDefs: [
                    {className: "width-200 dt-head-center", targets: [0,1]},
                    {className: "width-100 dt-body-right dt-head-center", targets: [2,3,4,5,6,7,8]}
                ],

                "footerCallback": function ( row, data, start, end, display ) {
                    var api = this.api(), data;

                    // Update footer
                    $(api.column(2).footer() ).html(
                        api.column(2, {page:'current'}).data().sum()
                    );
            
                    $(api.column(3).footer() ).html(
                        api.column(3, {page:'current'}).data().sum()
                    );
            
                    $(api.column(4).footer() ).html(
                        api.column(4, {page:'current'}).data().sum()
                    );
            
                    $(api.column(5).footer() ).html(
                        api.column(5, {page:'current'}).data().sum()
                    );
            
                    $(api.column(6).footer() ).html(
                        api.column(6, {page:'current'}).data().sum()
                    );
            
                    $(api.column(7).footer() ).html(
                        api.column(7, {page:'current'}).data().sum()
                    );
            
                    $(api.column(8).footer() ).html(
                        api.column(8, {page:'current'}).data().sum()
                    );
                }
            });
            
            // DataTable overrides
            $.fn.dataTable.ext.errMode = 'none';
            
            setProcessingForDataTable('reportTable');

            reportTable.on('draw', function () {
                addAriaToDataTable('reportTable', reportTable);
            });

            function constructUrl(methodName){
                var url= 'PatientDiscoverySummaryReport.do_sec' +
                    '?' + methodName + '=true' +
                    '&startDate=' + $('#startDate').val()+
                    '&endDate=' + $('#endDate').val() +
                    '&userId=' + $('#userId').val() +
                    '&organization=' + $('#organization').val() +
                    '&organizationName=' + $('#orgName').val() +
                    '&facility=' + $('#facility').val() +
                    '&facilityName=' + $('#facilityName').val() +
                    '&patientTypes=' + $('#patientTypes').val() +
                    '&sortBy=' + $('#reportTable').dataTable().fnSettings().aaSorting[0][0] +
                    '&sortOrder=' + $('#reportTable').dataTable().fnSettings().aaSorting[0][1];
                return url;
            }

            $('#searchButton').on('click', function () {
                var startDate = $('#startDate').val();
                var endDate = $('#endDate').val();

                var errorMessage = validateStartAndEndDate(startDate, endDate);
                
                if (errorMessage != '')
                {
                    //we have an error so show the error, and then don't send the ajax request
                    $('#errorMessage').html(errorMessage);
                    $('#errorMessage').show();

                    return false;
                } else {
                    //no error, let's make the call to populate the report
                    reportTable.ajax.url(constructUrl('doSearch')).load();
                }
            });

            $('.exportButton').on('click', function() {
                window.location.href = constructUrl($(this).data('method'));
                return false;
            });
            
            $('#startDate,#endDate').on('change', function () {
                //if either date changes, hide the error message if its not already hidden
                $('#errorMessage').hide();
            });
        });
    </script>
    <div class="form-container">
        <form name="patientDiscoverySummaryReportForm">
            <fieldset>
                <legend>Search Details</legend>
                <div id="errorMessage" class="bg-warning pad-15" style="display: none;"></div>
                <div class="width-450 pad-top-10" data-tooltip="<c:out value="${descriptors['startDateEndDateField']}"/>">
                    <div>
                        <label for="startDate">Start Date</label>
                        <date:date id="startDate" name="startDate" value="${startDateDefault}"/> <i>mm/dd/yyyy</i>
                    </div>
                    <div>
                        <label for="endDate">End Date</label>
                        <date:date id="endDate" name="endDate" value="${endDateDefault}"/> <i>mm/dd/yyyy</i>
                    </div>
                </div>
                <div>
                    <label for="userId">User ID</label>
                    <input title="Enter User ID" id="userId" name="userId" type="text" maxlength="255" size="30" data-tooltip="<c:out value="${descriptors['genericUserId']}" />" />
                </div>
                <div>
                    <label
                        title="Query based on Patient Preferred Facility from the dropdown list"
                        for="facility">Patient Preferred Facility</label> 
                    <select data-tooltip="<c:out value="${descriptors['patientPreferredFacilityFilter']}"/>" id="facility" name="facility" onchange = "document.getElementById('facilityName').value = this.options[this.selectedIndex].text;">
                        <option value="">ALL</option>
                        <c:forEach var="f" items="${facilities}">
                            <option value="<c:out value="${f.facilityStation}"/>"
                                    <c:choose>
                                        <c:when test="${f.facilityStation eq defaultUserFacility.facilityStation}">
                                            selected
                                        </c:when>
                                    </c:choose>>
                                <c:choose>
                                    <c:when test="${f.facilityName != ''}">
                                        <c:out value="${f.facilityName}"/>
                                    </c:when>
                                    <c:otherwise>
                                        <c:out value="${fn:split(f.facilityDns, '.')[0]}" />
                                    </c:otherwise>
                                </c:choose>
                                (<c:out value="${f.facilityStation}"/>)
                            </option>
                        </c:forEach>
                    </select>
                    <div>
                        <label
                            title="Query based on <c:out value="${organizationName}"/> Organization from the dropdown list"
                            for="organization"><c:out value="${organizationName}"/> Organization</label> 
                        <select data-tooltip="<c:out value="${descriptors['disclosuresSummaryReportOrganizationField']}"/>" id="organization" name="organization" onchange = "document.getElementById('orgName').value = this.options[this.selectedIndex].text;">
                            <option value="" selected>ALL</option>
                            <c:forEach var="r" items="${activeOrgs}">
                                <option value="%<c:out value="${r.orgOid}"/>">
                                    <c:out value="${r.orgName}"/>
                                </option>
                            </c:forEach>
                            <c:forEach var="r" items="${inactiveOrgs}">
                                <option value="%<c:out value="${r.orgOid}"/>">[INACTIVE] <c:out value="${r.orgName}"/></option>
                            </c:forEach>
                        </select>
                    </div>
                </div>
                <div>
                    <label for="patientTypes">Patient Types<span style="display:none;">"Choose whether you would like to filter by real patients only, test patients only, or both."</span></label>
                    <select data-tooltip="<c:out value="${descriptors['patientTypesField']}"/>" id="patientTypes" name="patientTypes">
                        <option value="3">ALL</option>
                        <option value="1" selected>Real Patients</option>
                        <option value="2">Test Patients</option>
                    </select>
                </div>
            </fieldset>
            <input type="hidden" name="orgName" id="orgName" value="<c:out value="${orgName}"/>">
            <input type="hidden" name="facilityName" id="facilityName" value="<c:out value="${facilityName}"/>">
        </form>
        <div>
            <input name="search" title="Search" class="button" type="submit" value="Search" id="searchButton"/>
        </div>
    </div>
    <div align="right" class="pad-top-5">
        <a href="#"><button class="exportButton" data-method="exportToExcel" title="Export to Excel">Export to Excel</button></a>
    </div>
    <div id="divReportContent">
        <table id="reportTable" class="display" width=100% cellspacing="0" role="presentation">
            <thead>
                <tr role="row">
                    <th role="columnheader"><span id="orgHeader" data-tooltip="<c:out value="${descriptors['eHealthExchangeOrganizationColumn']}" />"><c:out value="${organizationName}" /> Organization</span></th>
                    <th role="columnheader"><span id="facilityHeader" data-tooltip="<c:out value="${descriptors['vaFacilityColumn']}" />">Patient Preferred Facility</span></th>
                    <th role="columnheader"><span id="auditsHeader" data-tooltip="<c:out value="${descriptors['auditsColumn']}" />">Audits</span></th>
                    <th role="columnheader"><span id="uniqueRealPatientsHeader" data-tooltip="<c:out value="${descriptors['uniqueRealPatientsCountColumn']}" />">Unique Real Patients</span></th>
                    <th role="columnheader"><span id="matchesFoundRealPatientsHeader" data-tooltip="<c:out value="${descriptors['matchesFoundForRealPatientsCountColumn']}" />">Matches Found for Real Patients</span></th>
                    <th role="columnheader"><span id="matchFailsRealPatientsHeader" data-tooltip="<c:out value="${descriptors['failsForRealPatientsCountColumn']}" />">Match Fails for Real Patients</span></th>
                    <th role="columnheader"><span id="uniqueTestPatientsHeader" data-tooltip="<c:out value="${descriptors['uniqueTestPatientsCountColumn']}" />">Unique Test Patients</span></th>
                    <th role="columnheader"><span id="matchesFoundTestPatientsHeader" data-tooltip="<c:out value="${descriptors['matchesFoundForTestPatientsCountColumn']}" />">Matches Found for Test Patients</span></th>
                    <th role="columnheader"><span id="matchFailsTestPatientsHeader" data-tooltip="<c:out value="${descriptors['failsForTestPatientsCountColumn']}" />" data-tooltip-position="left">Match Fails for Test Patients</span></th>
                </tr>
            </thead>
            <tfoot>
                <tr role="row">
                    <%--Filled in by datatables, total--%>
                    <td role="gridcell" class="text-left footer-bold-pad-left-8">Total:</td>
                    <td role="gridcell"></td>
                    <td role="gridcell" class="text-right footer-bold-pad-right-9"></td>
                    <td role="gridcell" class="text-right footer-bold-pad-right-9"></td>
                    <td role="gridcell" class="text-right footer-bold-pad-right-9"></td>
                    <td role="gridcell" class="text-right footer-bold-pad-right-9"></td>
                    <td role="gridcell" class="text-right footer-bold-pad-right-9"></td>
                    <td role="gridcell" class="text-right footer-bold-pad-right-9"></td>
                    <td role="gridcell" class="text-right footer-bold-pad-right-9"></td>
                </tr>
            </tfoot>
        </table>
        <div aria-live="polite" role="status" id="reportTable_info" class="dataTables_info hidden">Shows audit summary data</div><%-- because we don't have the "Showing x of x" turned on for this table, we need this here to support aria --%>
    </div>
</f:mainTemplate>